@@ -1,4 +1,4 @@
-# Copyright 2022 Pablo Castellano, Oliver Smith
+# Copyright 2023 Pablo Castellano, Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
@@ -184,11 +184,11 @@ def command_qemu(args, arch, img_path, img_path_2nd=None):
     else:
         command += ["-device", "virtio-mouse-pci"]
     command += ["-device", "virtio-keyboard-pci"]
-    command += ["-netdev", "user,id=net,hostfwd=tcp::" + port_ssh + "-:22"]
+    command += ["-netdev", f"user,id=net,hostfwd=tcp:127.0.0.1:{port_ssh}-:22"]
     command += ["-device", "virtio-net-pci,netdev=net"]
 
     if arch == "x86_64":
-        command += ["-vga", "virtio"]
+        command += ["-device", "virtio-vga-gl"]
     elif arch == "aarch64":
         command += ["-M", "virt"]
         command += ["-cpu", "cortex-a57"]
@@ -286,8 +286,10 @@ def install_depends(args, arch):
         "qemu-audio-pa",
         "qemu-audio-sdl",
         "qemu-hw-display-virtio-gpu",
+        "qemu-hw-display-virtio-gpu-gl",
         "qemu-hw-display-virtio-gpu-pci",
         "qemu-hw-display-virtio-vga",
+        "qemu-hw-display-virtio-vga-gl",
         "qemu-system-" + arch,
         "qemu-ui-gtk",
         "qemu-ui-opengl",
